FileManager

Struct FileManager 

pub struct FileManager {}
Manages all the file system interactions

Implementations

Source

impl FileManager

pub fn boot_url() -> &'static str

pub async fn from_url(url: &str) -> Result<bool, Error>

Bootstraps the reload manager from a URL.

Arguments
  • url - The location of the configuration
pub fn file_exists(path: &str) -> bool

pub fn job_folder() -> &'static str

gets the name of the job folder

pub fn is_local() -> &'static str

pub fn job_path() -> &'static str

Gets the root to the root of the job path folder.

pub fn readfile(file_path: String) -> Result<String, Error>

Simple wrapper around the read_to_string

pub fn resolve_quadit_config_location() -> String

Generates the location of the quadit config.

pub fn job_exists(uuid: Uuid) -> bool

Test to see if the job folder exists. Used to validate if this is the first time the job has ran.

Arguments

uuid - The uuid of the job - Usually xxxxxxxx-xxxx-4xxx-Nxxx-xxxxxxxxxxxx.

pub fn quadit_home() -> String

Gets the home location of the user currently running quadit

pub fn load_quadit_config() -> Result<String, Error>

Loads the quadit config based on the resolved location.

pub fn filename_to_unit_name(target_path: &str) -> Result<String, String>

converts the quadlet file name to a service name with some additional checks.

pub fn container_file_deployed(job_path: &str, target_path: &str) -> bool

Test to see if a file exists in the container deployment location Currently ~/.config/containers/systemd/ but this may be expanded in later releases.

Arguments

job_path - The path to the job - Usually jobs/xxxxxxxx-xxxx-4xxx-Nxxx-xxxxxxxxxxxx. target_path - The path of the file in the git repo

pub fn get_files_in_directory(path: &str) -> Result<Vec<String>, Error>

Collects a directory contents as a vector of strings

pub fn are_identical(file_name1: &str, file_name2: &str) -> bool

Compare the bytes of two files incrementally to see if they differ.

Arguments

file_name1 - The first file to compare. file_name2 - The second file to compare.

pub fn deploy_container_file( job_path: &str, target_path: &str, ) -> Result<String, String>

Copy to the users ~/.config/containers/systemd/

Arguments

job_path - The location that the repo has been copied to target_path - The location of the .container file in the repo